CVXOPT
======

Python Software for Convex Optimization

* [Website](http://cvxopt.org)
* [Documentation](http://cvxopt.org/userguide)
* [Google Groups forum](https://groups.google.com/forum/#!forum/cvxopt)


Release info
------------

[![License](https://img.shields.io/badge/license-GPL3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0.en.html)
[![GitHub release](https://img.shields.io/github/release/cvxopt/cvxopt.svg)](https://github.com/cvxopt/cvxopt/releases/latest)
[![PyPI](https://img.shields.io/pypi/v/cvxopt.svg)](https://pypi.python.org/pypi/cvxopt)
[![Anaconda-Server Badge](https://anaconda.org/conda-forge/cvxopt/badges/version.svg)](https://anaconda.org/conda-forge/cvxopt)


Related projects
----------------

* [CVXOPT wheels](https://github.com/cvxopt/cvxopt-wheels)
* [CVXOPT conda-forge package](https://github.com/conda-forge/cvxopt-feedstock)
* [Julia interface to CVXOPT](https://github.com/cvxopt/CVXOPT.jl)
* [MATLAB interface to CVXOPT](https://github.com/cvxopt/cvxopt-matlab)


Build status
------------

[![Linux build Actions Status](https://github.com/cvxopt/cvxopt/workflows/Linux%20build/badge.svg)](https://github.com/cvxopt/cvxopt/actions)
 [![macOS build Actions Status](https://github.com/cvxopt/cvxopt/workflows/macOS%20build/badge.svg)](https://github.com/cvxopt/cvxopt/actions) [![Windows build Actions Status](https://github.com/cvxopt/cvxopt/workflows/Windows%20build/badge.svg)](https://github.com/cvxopt/cvxopt/actions)
